pub enum CancellationOutcome<Worker, Plan>where
Worker: Behavior,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,{
WorkerReturned,
ProxyInputRejected,
ProxyReported {
outcome: ProxyOutcome<Worker, Plan>,
},
}Expand description
Complete worker-custody result of one cancelled management operation.
Variants
WorkerReturned
The complete worker submission returned through the cancellation reply.
ProxyInputRejected
The emitted proxy input was rejected and moved to diagnostic custody.
ProxyReported
The proxy produced a late result retained by the lifecycle owner.
Fields

outcome: ProxyOutcome<Worker, Plan>Auto Trait Implementations
impl<Worker, Plan> Freeze for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + Freeze,
<<Worker as Behavior>::Protocol as Protocol>::Msg: Freeze,
Worker: Freeze,
Plan: Freeze,
<Plan as ActivationPlan>::Ready: Freeze,
<Worker as Behavior>::Error: Freeze,
<Plan as ActivationPlan>::Rejection: Freeze,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: Freeze,
<Worker as Behavior>::Sends: Freeze,
<Worker as Behavior>::Ph: Freeze,
impl<Worker, Plan> RefUnwindSafe for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + RefUnwindSafe,
<<Worker as Behavior>::Protocol as Protocol>::Msg: RefUnwindSafe,
Worker: RefUnwindSafe,
Plan: RefUnwindSafe,
<Plan as ActivationPlan>::Ready: RefUnwindSafe,
<Worker as Behavior>::Error: RefUnwindSafe,
<Plan as ActivationPlan>::Rejection: RefUnwindSafe,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: RefUnwindSafe,
<Worker as Behavior>::Sends: RefUnwindSafe,
<Worker as Behavior>::Ph: RefUnwindSafe,
<<Worker as Behavior>::Birth as BirthMode>::Child: RefUnwindSafe,
impl<Worker, Plan> Send for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + Send,
<<Worker as Behavior>::Protocol as Protocol>::Msg: Send,
Worker: Send,
<Worker as Behavior>::Error: Send,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: Send,
<Worker as Behavior>::Sends: Send,
<Worker as Behavior>::Ph: Send,
<<Worker as Behavior>::Birth as BirthMode>::Child: Send,
impl<Worker, Plan> Sync for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + Sync,
<<Worker as Behavior>::Protocol as Protocol>::Msg: Sync,
Worker: Sync,
Plan: Sync,
<Plan as ActivationPlan>::Ready: Sync,
<Worker as Behavior>::Error: Sync,
<Plan as ActivationPlan>::Rejection: Sync,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: Sync,
<Worker as Behavior>::Sends: Sync,
<Worker as Behavior>::Ph: Sync,
<<Worker as Behavior>::Birth as BirthMode>::Child: Sync,
impl<Worker, Plan> Unpin for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + Unpin,
<<Worker as Behavior>::Protocol as Protocol>::Msg: Unpin,
Worker: Unpin,
Plan: Unpin,
<Plan as ActivationPlan>::Ready: Unpin,
<Worker as Behavior>::Error: Unpin,
<Plan as ActivationPlan>::Rejection: Unpin,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: Unpin,
<Worker as Behavior>::Sends: Unpin,
<Worker as Behavior>::Ph: Unpin,
<<Worker as Behavior>::Birth as BirthMode>::Child: Unpin,
impl<Worker, Plan> UnsafeUnpin for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + UnsafeUnpin,
<<Worker as Behavior>::Protocol as Protocol>::Msg: UnsafeUnpin,
Worker: UnsafeUnpin,
Plan: UnsafeUnpin,
<Plan as ActivationPlan>::Ready: UnsafeUnpin,
<Worker as Behavior>::Error: UnsafeUnpin,
<Plan as ActivationPlan>::Rejection: UnsafeUnpin,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: UnsafeUnpin,
<Worker as Behavior>::Sends: UnsafeUnpin,
<Worker as Behavior>::Ph: UnsafeUnpin,
impl<Worker, Plan> UnwindSafe for CancellationOutcome<Worker, Plan>where
<<Worker as Behavior>::Protocol as Protocol>::Addr: Sized + UnwindSafe,
<<Worker as Behavior>::Protocol as Protocol>::Msg: UnwindSafe,
Worker: UnwindSafe,
Plan: UnwindSafe,
<Plan as ActivationPlan>::Ready: UnwindSafe,
<Worker as Behavior>::Error: UnwindSafe,
<Plan as ActivationPlan>::Rejection: UnwindSafe,
<<<Worker as Behavior>::Protocol as Protocol>::Addr as EndpointAddress>::Established<<Worker as Behavior>::Protocol>: UnwindSafe,
<Worker as Behavior>::Sends: UnwindSafe,
<Worker as Behavior>::Ph: UnwindSafe,
<<Worker as Behavior>::Birth as BirthMode>::Child: UnwindSafe,