DiagnosticAction

Enum DiagnosticAction 

pub enum DiagnosticAction<Route, Diagnostic> {
    Deliver {
        route: Route,
        diagnostic: Diagnostic,
    },
    Terminal {
        diagnostic: Diagnostic,
    },
}
One complete diagnostic selected for delivery or terminal custody.

A route for another diagnostic protocol cannot become an action item:

ⓘ
fn require_action<Item: behavior::ActionItem>(_: Item) {}
let route = behavior::Recipient::<behavior::MessageProtocol<behavior::MailAddr, u8>>::global(behavior::MailAddr(1));
require_action(behavior_actors::atomic::DiagnosticAction::deliver(route, String::from("failed")));

Variants



Deliver

Fields

route: Route
diagnostic: Diagnostic


Terminal

Fields

diagnostic: Diagnostic

Implementations

Source

impl<Route, Diagnostic> DiagnosticAction<Route, Diagnostic>

pub const fn deliver(route: Route, diagnostic: Diagnostic) -> Self

Construct one routed diagnostic without cloning its payload.

pub const fn terminal(diagnostic: Diagnostic) -> Self

Construct one route-free terminal diagnostic.