InterruptedWorker

Enum InterruptedWorker 

pub enum InterruptedWorker<Worker, Plan>
where Worker: Behavior, Plan: ActivationPlan, BehaviorAddr<Worker>: EndpointAddress, StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
{ Submission(WorkerSubmission<Worker, Plan>), ProxyInputRejected, ProxyReported(ProxyOutcome<Worker, Plan>), }
Complete worker disposition when a start is interrupted before availability.

Variants



Submission(WorkerSubmission<Worker, Plan>)

The worker never left the supervisor’s local submission.



ProxyInputRejected

The emitted proxy input was rejected and moved to diagnostic custody.



ProxyReported(ProxyOutcome<Worker, Plan>)

The proxy returned the exact result of the interrupted input.