MemberStatus

Enum MemberStatus 

pub enum MemberStatus<Service>
where Service: Protocol, Service::Addr: EndpointAddress,
{ CreatingProxy, WaitingForActivation, AwaitingProxy, Ready { proxy: EstablishedRecipient<Service>, }, Empty, Recovering, Stopping, Retired, }
Read-only phase of one fixed roster member.

Variants



CreatingProxy

The stable proxy is not committed yet.



WaitingForActivation

The proxy is waiting for global activation capacity.



AwaitingProxy

Initial or replacement input is awaiting its atomic proxy outcome.



Ready

The stable proxy is ready to accept service messages.

Fields

proxy: EstablishedRecipient<Service>

Exact capability of the ready stable proxy, never its worker.



Empty

The stable proxy has no current worker.



Recovering

The role belongs to one coordinated recovery.



Stopping

The stable proxy is retiring.



Retired

The role no longer owns a stable proxy.