PoolRecovery

Enum PoolRecovery 

pub enum PoolRecovery<Source> {
    Permanent {
        source: Source,
        limit: RestartLimit,
        release: RestartRelease,
        failure: PoolFailureReaction,
    },
    Transient {
        source: Source,
        limit: RestartLimit,
        release: RestartRelease,
        failure: PoolFailureReaction,
    },
    Temporary {
        failure: PoolFailureReaction,
    },
}
Direct-worker eligibility, source, restart policy, and failure reaction.

Variants



Permanent

Recover after normal and abnormal worker stops.

Fields

source: Source

Typed capability used by Bombay to prepare a replacement worker.

limit: RestartLimit

Sliding-window restart admission limit.

release: RestartRelease

Immediate or delayed release policy.

failure: PoolFailureReaction

Disposition when preparation or restart admission fails.



Transient

Recover only after abnormal worker stops.

Fields

source: Source

Typed capability used by Bombay to prepare a replacement worker.

limit: RestartLimit

Sliding-window restart admission limit.

release: RestartRelease

Immediate or delayed release policy.

failure: PoolFailureReaction

Disposition when preparation or restart admission fails.



Temporary

Never create a replacement worker.

Fields

failure: PoolFailureReaction

Disposition after the role retires.

Implementations

Source

impl<Source> PoolRecovery<Source>

pub const fn permanent( source: Source, limit: RestartLimit, release: RestartRelease, failure: PoolFailureReaction, ) -> Self

Recover after every exact worker stop.

pub const fn transient( source: Source, limit: RestartLimit, release: RestartRelease, failure: PoolFailureReaction, ) -> Self

Recover only after abnormal worker stops.

Source

impl PoolRecovery<Never>

pub const fn temporary(failure: PoolFailureReaction) -> Self

Retire stopped workers without a source placeholder.