ProxyDiagnostic

Enum ProxyDiagnostic 

pub enum ProxyDiagnostic<W, P>{
    UnexpectedWorkerStart {
        phase: ProxyPhase,
        workers: CreationsSettled<BehaviorAddr<W>, StopOnShutdown<W>>,
    },
    UnexpectedWorkerStop {
        phase: ProxyPhase,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
    UnexpectedWorkerInitialization {
        phase: ProxyPhase,
        initialization: WorkerInitializationReport<W, P>,
    },
    UnexpectedWorkerActivation {
        phase: ProxyPhase,
        activation: WorkerActivation<W, P>,
    },
    UnexpectedWorkerShutdown {
        phase: ProxyPhase,
        shutdown: EstablishedShutdownResolved<W::Protocol>,
    },
}
Lifecycle input returned without changing the current proxy state.

Variants



UnexpectedWorkerStart

A worker-creation settlement did not belong to the current start.



UnexpectedWorkerStop

A worker stop did not belong to the worker expected by this phase.

Fields



UnexpectedWorkerInitialization

A child-host result did not belong to the worker expected by this phase.

Fields

initialization: WorkerInitializationReport<W, P>


UnexpectedWorkerActivation

An activation input did not belong to the worker expected by this phase.

Fields

activation: WorkerActivation<W, P>


UnexpectedWorkerShutdown

An exact shutdown resolution did not belong to the current worker drain.