ProxyDrain

Enum ProxyDrain 

pub enum ProxyDrain<W, P>{
    InitializationRejected {
        failure: WorkerInitializationFailure,
        activation: P,
        shutdown: Option<EstablishedShutdownResolved<W::Protocol>>,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
    InitializationStopped {
        activation: P,
        observed: Option<ChildStopped<BehaviorAddr<W>>>,
        returned: ChildStopped<BehaviorAddr<W>>,
    },
    InitializationCompleted {
        permit: ActivationPermit<W>,
        activation: P,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
    ActivationStartRejected {
        request: BeginActivation<W, P>,
        reason: ActivationStartRejection,
        shutdown: Option<EstablishedShutdownResolved<W::Protocol>>,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
    ActivationRejected {
        rejection: P::Rejection,
        shutdown: Option<EstablishedShutdownResolved<W::Protocol>>,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
    ActivationCompleted {
        readiness: P::Ready,
        stopped: ChildStopped<BehaviorAddr<W>>,
    },
}
Complete retained values proving how one unavailable worker was returned.

Variants



InitializationRejected

Pure initialization rejected after the worker was committed.



InitializationStopped

Initialization stopped after the worker was committed.

Fields

activation: P


InitializationCompleted

Initialization completed, but an exact worker stop prevented activation.

Fields

activation: P


ActivationStartRejected

The activation request was rejected before the plan ran.



ActivationRejected

The activation plan rejected after its request was accepted.



ActivationCompleted

Activation completed, but an exact worker stop prevented availability.

Fields

readiness: P::Ready