pub enum ReplacementFailure<Worker, Plan>where
Worker: Behavior,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,{
ProxyRefused {
worker: Worker,
activation: Plan,
phase: ProxyPhase,
},
WorkerAttemptsExhausted {
worker: Worker,
activation: Plan,
},
WorkerCreationRejected {
rejection: WorkerCreationRejection<Worker>,
activation: Plan,
stopped: Option<ChildStopped<BehaviorAddr<Worker>>>,
},
WorkerUnavailable {
drain: ProxyDrain<Worker, Plan>,
},
}Expand description
Exact replacement failure values not retained by the next service state.
Variants
ProxyRefused
StableProxy refused the input without changing its current worker.
WorkerAttemptsExhausted
StableProxy returned the worker after exhausting fresh attempt IDs.
WorkerCreationRejected
Successor creation failed before a worker was committed.
Fields

rejection: WorkerCreationRejection<Worker>
activation: Plan
stopped: Option<ChildStopped<BehaviorAddr<Worker>>>A committed successor could not become available and was drained.