WorkerPreparationFailureReason

Enum WorkerPreparationFailureReason 

pub enum WorkerPreparationFailureReason<'a, Role, WorkerRejection, SourceRejection> {
    WorkerRejected {
        role: &'a Role,
        reason: &'a WorkerRejection,
    },
    SourceRejected(&'a SourceRejection),
    InterpreterFault(InterpreterFault),
    Unattempted,
}
Exact borrowed reason for one operating worker-preparation failure.

Variants



WorkerRejected

The source accepted the request but rejected one selected worker.

Fields

role: &'a Role

Exact semantic role whose worker was rejected.

reason: &'a WorkerRejection

Source-selected worker rejection.



SourceRejected(&'a SourceRejection)

The source rejected the complete request before preparing a worker.



InterpreterFault(InterpreterFault)

The interpreter returned the request with controlled corruption evidence.



Unattempted

Product interpretation stopped before attempting the request.