pub struct CancelAuthority<Key> { /* private fields */ }Expand description
Affine authority to cancel one accepted start or replacement.
ⓘ
fn duplicate<Key>(authority: behavior_actors::atomic::CancelAuthority<Key>) {
let first = authority;
let second = authority;
}Applications cannot forge an operation authority from a key and number:
ⓘ
let _authority = behavior_actors::atomic::CancelAuthority {
key: "search",
operation: 1,
};Implementations