PreparedWorker

Struct PreparedWorker 

pub struct PreparedWorker<Role, W, P> {
    pub role: Role,
    pub submission: WorkerSubmission<W, P>,
}
One semantic role and its complete prepared worker submission.

Fields

role: Role

Application role owned by this worker relationship.

submission: WorkerSubmission<W, P>

Worker behavior and activation work prepared for the role.