ProxyControl

Struct ProxyControl 

pub struct ProxyControl<W, P> { /* private fields */ }
Owner-only operation accepted by super::StableProxy.

Implementations

Source

impl<W> ProxyControl<W, ImmediateActivation>

pub const fn start(worker: W) -> Self

Start an immediately ready worker without an unused plan argument.

pub const fn replace(worker: W) -> Self

Replace with an immediately ready worker.

Source

impl<W, P> ProxyControl<W, P>

pub const fn shutdown() -> Self

Shut down the proxy without an unused worker or activation input.

pub const fn start_with(worker: W, activation: P) -> Self

Start a worker with application-defined activation work.

pub const fn replace_with(worker: W, activation: P) -> Self

Replace with a worker using application-defined activation work.