ProxyOutcomeFailure

Struct ProxyOutcomeFailure 

pub struct ProxyOutcomeFailure<Role, Worker, Plan>
where Worker: Behavior, Plan: ActivationPlan, BehaviorAddr<Worker>: EndpointAddress, StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
{ /* private fields */ }
Complete role and proxy outcome retained after initial startup failed.

Implementations

Source

impl<Role, Worker, Plan> ProxyOutcomeFailure<Role, Worker, Plan>
where Worker: Behavior, Plan: ActivationPlan, BehaviorAddr<Worker>: EndpointAddress, StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,

pub fn role(&self) -> &Role

Inspect the semantic role without exposing its private shared storage.

pub const fn outcome(&self) -> &ProxyOutcome<Worker, Plan>

Inspect the complete non-ready proxy outcome.