pub struct Recovery<Source> { /* private fields */ }Expand description
Complete eligibility, worker source, and policy for recovery.
Implementations
Sourceimpl<Source> Recovery<Source>
impl<Source> Recovery<Source>
Sourcepub const fn permanent(
source: Source,
strategy: Strategy,
limit: RestartLimit,
release: RestartRelease,
) -> Self
pub const fn permanent( source: Source, strategy: Strategy, limit: RestartLimit, release: RestartRelease, ) -> Self
Recover after normal or abnormal worker stop through this source.
Sourcepub const fn transient(
source: Source,
strategy: Strategy,
limit: RestartLimit,
release: RestartRelease,
) -> Self
pub const fn transient( source: Source, strategy: Strategy, limit: RestartLimit, release: RestartRelease, ) -> Self
Recover only after abnormal worker stop through this source.