RestartRelease

Struct RestartRelease 

pub struct RestartRelease { /* private fields */ }
Checked delay schedule for successive automatic recoveries.

Implementations

Source

impl RestartRelease

pub const fn immediate() -> Self

Release every eligible recovery without a timer prerequisite.

pub fn constant(delay: Duration) -> Result<Self, RestartReleaseError>

Use one positive delay for every eligible recovery.

pub fn linear( initial: Duration, maximum: Duration, ) -> Result<Self, RestartReleaseError>

Increase delay linearly from a positive initial value up to a maximum.

pub fn exponential( initial: Duration, maximum: Duration, ) -> Result<Self, RestartReleaseError>

Increase delay exponentially from a positive initial value up to a maximum.