StartingWorkerPreparation

Struct StartingWorkerPreparation 

pub struct StartingWorkerPreparation<Source, Role, Worker, Plan>
where Source: WorkerSource<Role, Worker, Plan>, Worker: Behavior + Send, Plan: ActivationPlan,
{ /* private fields */ }
Source work after one accepted start and before its first submission.

Only this phase can return a source rejection. Once it accepts a first submission, the returned pending request has a nonempty prepared prefix and can report only worker-specific rejection for later roles.

Implementations

Source

impl<Source, Role, Worker, Plan> StartingWorkerPreparation<Source, Role, Worker, Plan>
where Source: WorkerSource<Role, Worker, Plan>, Worker: Behavior + Send, Plan: ActivationPlan,

pub fn source_and_role(&mut self) -> (&mut Source, &Role)

Borrow the source and first selected application role.

pub fn accept( self, submission: WorkerSubmission<Worker, Plan>, ) -> ControlFlow<WorkerPreparation<Source, Role, Worker, Plan>, PendingWorkerPreparation<Source, Role, Worker, Plan>>

Accept the first submission and advance or complete the ordered group.

pub fn reject( self, reason: Source::WorkerRejection, ) -> WorkerPreparation<Source, Role, Worker, Plan>

Return an exact worker rejection for the first selected role.

pub fn reject_source( self, reason: Source::SourceRejection, ) -> WorkerPreparation<Source, Role, Worker, Plan>

Return the source and its exact rejection before any worker submission.