WorkerActivation

Struct WorkerActivation 

pub struct WorkerActivation<W, P>{ /* private fields */ }
Exact input produced by one accepted worker activation request.

Implementations

Source

impl<W, P> WorkerActivation<W, P>

pub fn worker(&self) -> WorkerAttempt

Worker creation correlation carried by this input.

pub fn into_ready(self) -> Result<P::Ready, Self>

Consume readiness only when this is the ready alternative.

pub fn into_rejection(self) -> Result<P::Rejection, Self>

Consume the application rejection only when this is the rejected alternative.