pub enum DiagnosticAction<Route, Diagnostic> {
Deliver {
route: Route,
diagnostic: Diagnostic,
},
Terminal {
diagnostic: Diagnostic,
},
}Expand description
One complete diagnostic selected for delivery or terminal custody.
A route for another diagnostic protocol cannot become an action item:
ⓘ
fn require_action<Item: behavior::ActionItem>(_: Item) {}
let route = behavior::Recipient::<behavior::MessageProtocol<behavior::MailAddr, u8>>::global(behavior::MailAddr(1));
require_action(behavior_actors::atomic::DiagnosticAction::deliver(route, String::from("failed")));Variants
Implementations
Sourceimpl<Route, Diagnostic> DiagnosticAction<Route, Diagnostic>
impl<Route, Diagnostic> DiagnosticAction<Route, Diagnostic>