pub enum FixedCommand<A, Role, Service>{
Status {
reply_to: ReplyRoute<MessageProtocol<A, FixedSnapshot<Service>>>,
},
Capability {
role: Role,
reply_to: ReplyRoute<MessageProtocol<A, CapabilityResult<Role, Service>>>,
},
Shutdown,
}Expand description
Management input accepted by one fixed supervisor.
A recipient for another reply protocol cannot be substituted:
ⓘ
#[derive(Clone, Copy, Eq, PartialEq)]
struct RuntimeAddress;
impl behavior::Address for RuntimeAddress { type Nonce = u64; }
#[derive(Clone)]
struct Endpoint;
struct Installed<B: behavior::Behavior>(Endpoint, std::sync::mpsc::Sender<B::Event>);
impl<B: behavior::Behavior> Clone for Installed<B> {
fn clone(&self) -> Self { Self(self.0.clone(), self.1.clone()) }
}
impl behavior::EndpointAddress for RuntimeAddress {
type Established<P> = Endpoint where P: behavior::Protocol<Addr = Self>;
type Installed<B> = Installed<B>
where B: behavior::Behavior<Protocol: behavior::Protocol<Addr = Self>>;
fn recipient<B>(installed: &Self::Installed<B>) -> Endpoint
where B: behavior::Behavior<Protocol: behavior::Protocol<Addr = Self>> {
installed.0.clone()
}
}
struct Service;
impl behavior::Protocol for Service {
type Addr = RuntimeAddress;
type Msg = u8;
}
let wrong = behavior::Recipient::<
behavior::MessageProtocol<RuntimeAddress, u8>
>::global(RuntimeAddress);
let _: behavior_actors::atomic::FixedCommand<RuntimeAddress, u16, Service> =
behavior_actors::atomic::FixedCommand::status(wrong);Variants
Status
Query every member status in declaration order.
Fields

reply_to: ReplyRoute<MessageProtocol<A, FixedSnapshot<Service>>>Temporary logical or exact status recipient.
Capability
Query the stable service capability for one semantic role.
Fields

role: RoleSubmitted role value, returned in every capability result.

reply_to: ReplyRoute<MessageProtocol<A, CapabilityResult<Role, Service>>>Temporary logical or exact capability-result recipient.
Shutdown
Close recovery admission and retire the complete owned actor graph.
Implementations
Sourceimpl<A, Role, Service> FixedCommand<A, Role, Service>
impl<A, Role, Service> FixedCommand<A, Role, Service>
Sourcepub fn capability<Route>(role: Role, reply_to: Route) -> Self
pub fn capability<Route>(role: Role, reply_to: Route) -> Self
Construct one semantic-role capability query.