pub enum ProxyOutcome<W, P>where
W: Behavior,
P: ActivationPlan,
StopOnShutdown<W>: Behavior<Protocol = W::Protocol, Ph = W::Ph, Birth = W::Birth>,
<W::Protocol as Protocol>::Addr: EndpointAddress,{
Initial {
outcome: InitialWorkerOutcome<W, P>,
},
Replacement {
outcome: ReplacementOutcome<W, P>,
},
WorkerStopped {
worker: WorkerAttempt,
stopped: ChildStopped<BehaviorAddr<W>>,
},
Unavailable {
sender: BehaviorAddr<W>,
phase: ProxyPhase,
command: <W::Protocol as Protocol>::Msg,
},
}Expand description
Complete report emitted to the structural owner of a stable proxy.
Variants
Initial
Result of the first submitted worker.
Fields

outcome: InitialWorkerOutcome<W, P>Replacement
Result of one submitted replacement worker.
Fields

outcome: ReplacementOutcome<W, P>WorkerStopped
The exact ready worker stopped and left the stable service unavailable.
A service command arrived while no worker was ready.