pub enum UnexpectedExit {
KeepEmpty,
Retire,
}Expand description
Policy after an unrequested exact worker stop leaves its proxy empty.
Variants
KeepEmpty
Retain the key and empty stable proxy for explicit replacement or stop.
Retire
Drain the stable proxy and release the key.