pub enum WorkerCreationRejection<W>where
W: Behavior,{
NamespaceExhausted {
worker: W,
},
WorkerRejected {
worker: W,
error: W::Error,
},
WorkerPanicked {
worker: W,
},
HostRejected {
recovery: WorkerRecovery<W>,
reason: CreationRejection,
},
CreationRejected {
worker: W,
reason: CreationRejection,
},
InterpreterCorrupt {
worker: W,
fault: InterpreterFault,
},
InterpretationSkipped {
worker: W,
},
}Expand description
Complete rejection returned by one worker-creation attempt.
Variants
NamespaceExhausted
Bombay could not route the creator’s child creation.
Fields

worker: WWorkerRejected
The worker’s pure initialization transition rejected.
WorkerPanicked
The worker’s pure initialization panicked before host commitment.
Fields

worker: WHostRejected
Host establishment rejected after initialization produced actions.
CreationRejected
The creation capability lawfully rejected and returned the worker.
InterpreterCorrupt
The interpreter violated its creation contract and returned the worker.
InterpretationSkipped
Product traversal stopped before attempting this worker creation.
Fields

worker: WAuto Trait Implementations
impl<W> Freeze for WorkerCreationRejection<W>
impl<W> RefUnwindSafe for WorkerCreationRejection<W>where
W: RefUnwindSafe,
<W as Behavior>::Error: RefUnwindSafe,
<W as Behavior>::Sends: RefUnwindSafe,
<W as Behavior>::Ph: RefUnwindSafe,
<<W as Behavior>::Birth as BirthMode>::Child: RefUnwindSafe,
impl<W> Send for WorkerCreationRejection<W>
impl<W> Sync for WorkerCreationRejection<W>
impl<W> Unpin for WorkerCreationRejection<W>
impl<W> UnsafeUnpin for WorkerCreationRejection<W>where
W: UnsafeUnpin,
<W as Behavior>::Error: UnsafeUnpin,
<W as Behavior>::Sends: UnsafeUnpin,
<W as Behavior>::Ph: UnsafeUnpin,
impl<W> UnwindSafe for WorkerCreationRejection<W>where
W: UnwindSafe,
<W as Behavior>::Error: UnwindSafe,
<W as Behavior>::Sends: UnwindSafe,
<W as Behavior>::Ph: UnwindSafe,
<<W as Behavior>::Birth as BirthMode>::Child: UnwindSafe,