pub struct AssignWorker<P, Job>{ /* private fields */ }Expand description
One exact direct-worker delivery whose complete settlement returns to its pool.
Implementations
Sourceimpl<P, Job> AssignWorker<P, Job>
impl<P, Job> AssignWorker<P, Job>
Sourcepub fn target(&self) -> EstablishedRecipient<P>
pub fn target(&self) -> EstablishedRecipient<P>
Return a clone of the exact worker recipient selected by the pool. The assignment and its accepted receipt remain inside this request.
Sourcepub async fn settle<Host, RootEvent, Path>(
progress: &mut Option<InterpretationProgress<Self, <Self as ActionItem>::Custody, ItemSettlement<Self, AssignmentReceipt, ExactDeliveryReason, Never>>>,
host: &mut Host,
)where
Host: InterpretItem<EstablishedDelivery<P>, RootEvent, Path>,
<P::Addr as RecipientAddress>::Established<P>: Send,
Job: Send,
pub async fn settle<Host, RootEvent, Path>(
progress: &mut Option<InterpretationProgress<Self, <Self as ActionItem>::Custody, ItemSettlement<Self, AssignmentReceipt, ExactDeliveryReason, Never>>>,
host: &mut Host,
)where
Host: InterpretItem<EstablishedDelivery<P>, RootEvent, Path>,
<P::Addr as RecipientAddress>::Established<P>: Send,
Job: Send,
Attempt the lower worker delivery while the complete request or partial assignment receipt remains in the caller’s original interpretation slot.