pub struct FixedBuilder<Factory, Role, Source, DiagnosticRoute, LifecycleRoute> { /* private fields */ }Expand description
Inferred construction value that owns every required supervisor input.
Implementations
Sourceimpl<Factory, Role, Source, DiagnosticRoute> FixedBuilder<Factory, Role, Source, DiagnosticRoute, Infallible>
impl<Factory, Role, Source, DiagnosticRoute> FixedBuilder<Factory, Role, Source, DiagnosticRoute, Infallible>
Sourcepub fn publish_lifecycle<Route>(
self,
route: Route,
) -> FixedBuilder<Factory, Role, Source, DiagnosticRoute, Route>
pub fn publish_lifecycle<Route>( self, route: Route, ) -> FixedBuilder<Factory, Role, Source, DiagnosticRoute, Route>
Publish lifecycle events through one typed route.
Sourceimpl<Factory, Role, Source, DiagnosticRoute, LifecycleRoute> FixedBuilder<Factory, Role, Source, DiagnosticRoute, LifecycleRoute>
impl<Factory, Role, Source, DiagnosticRoute, LifecycleRoute> FixedBuilder<Factory, Role, Source, DiagnosticRoute, LifecycleRoute>
Sourcepub fn build<Worker, Plan, Rejection>(
self,
) -> Result<FixedSupervisor<Role, Worker, Plan, Source, DiagnosticRoute, LifecycleRoute>, FixedConstructionRejected<Factory, Role, Worker, Plan, Rejection, Source, DiagnosticRoute, LifecycleRoute>>where
Factory: FnMut(&Role) -> Result<WorkerSubmission<Worker, Plan>, Rejection>,
Role: Send + Sync,
Source: WorkerSource<Role, Worker, Plan>,
Worker: Behavior + Send,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
pub fn build<Worker, Plan, Rejection>(
self,
) -> Result<FixedSupervisor<Role, Worker, Plan, Source, DiagnosticRoute, LifecycleRoute>, FixedConstructionRejected<Factory, Role, Worker, Plan, Rejection, Source, DiagnosticRoute, LifecycleRoute>>where
Factory: FnMut(&Role) -> Result<WorkerSubmission<Worker, Plan>, Rejection>,
Role: Send + Sync,
Source: WorkerSource<Role, Worker, Plan>,
Worker: Behavior + Send,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
Prepare every initial worker in declaration order or return all custody.