pub struct FixedLifecycle<Role, Worker, Plan>where
Worker: Behavior,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,{ /* private fields */ }Expand description
One lifecycle message published by a fixed supervisor.
The role is stored once even though the lifecycle change is exhaustive.
FixedLifecycle::event exposes a borrowed application view without
requiring Role: Clone.
Implementations
Sourceimpl<Role, Worker, Plan> FixedLifecycle<Role, Worker, Plan>where
Worker: Behavior,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
impl<Role, Worker, Plan> FixedLifecycle<Role, Worker, Plan>where
Worker: Behavior,
Plan: ActivationPlan,
BehaviorAddr<Worker>: EndpointAddress,
StableProxy<Worker, Plan>: Behavior<Protocol = Worker::Protocol>,
Sourcepub fn event(&self) -> FixedLifecycleEvent<'_, Role, Worker, Plan>
pub fn event(&self) -> FixedLifecycleEvent<'_, Role, Worker, Plan>
Inspect the complete lifecycle change while borrowing its role and affine payloads.