pub struct RestartRelease { /* private fields */ }Expand description
Checked delay schedule for successive automatic recoveries.
Implementations
Sourceimpl RestartRelease
impl RestartRelease
Sourcepub fn constant(delay: Duration) -> Result<Self, RestartReleaseError>
pub fn constant(delay: Duration) -> Result<Self, RestartReleaseError>
Use one positive delay for every eligible recovery.
Sourcepub fn linear(
initial: Duration,
maximum: Duration,
) -> Result<Self, RestartReleaseError>
pub fn linear( initial: Duration, maximum: Duration, ) -> Result<Self, RestartReleaseError>
Increase delay linearly from a positive initial value up to a maximum.
Sourcepub fn exponential(
initial: Duration,
maximum: Duration,
) -> Result<Self, RestartReleaseError>
pub fn exponential( initial: Duration, maximum: Duration, ) -> Result<Self, RestartReleaseError>
Increase delay exponentially from a positive initial value up to a maximum.