pub struct WorkerActivation<W, P>{ /* private fields */ }Expand description
Exact input produced by one accepted worker activation request.
Implementations
Sourceimpl<W, P> WorkerActivation<W, P>
impl<W, P> WorkerActivation<W, P>
Sourcepub fn worker(&self) -> WorkerAttempt
pub fn worker(&self) -> WorkerAttempt
Worker creation correlation carried by this input.
Sourcepub fn into_ready(self) -> Result<P::Ready, Self>
pub fn into_ready(self) -> Result<P::Ready, Self>
Consume readiness only when this is the ready alternative.
Sourcepub fn into_rejection(self) -> Result<P::Rejection, Self>
pub fn into_rejection(self) -> Result<P::Rejection, Self>
Consume the application rejection only when this is the rejected alternative.